summaryrefslogtreecommitdiff
path: root/xmloff
diff options
context:
space:
mode:
authorJulien Nabet <serval2412@yahoo.fr>2014-06-29 13:10:56 +0200
committerJulien Nabet <serval2412@yahoo.fr>2014-06-29 13:15:51 +0200
commit430484932e1254f7076321c2a7b3ec3df1512896 (patch)
treea14900e50ad012302814e4272934639578e01435 /xmloff
parent3b8ab58008fcbca3c581ef827e5af07eb72b23ee (diff)
Typo: beeing->being
Change-Id: I34937e400ac8576154d33e1e11b80690222f532c
Diffstat (limited to 'xmloff')
-rw-r--r--xmloff/source/forms/elementimport.hxx4
-rw-r--r--xmloff/source/forms/layerexport.hxx2
-rw-r--r--xmloff/source/text/txtflde.cxx2
3 files changed, 4 insertions, 4 deletions
diff --git a/xmloff/source/forms/layerexport.hxx b/xmloff/source/forms/layerexport.hxx
index 419e458f1cfe..f7d902389d3e 100644
--- a/xmloff/source/forms/layerexport.hxx
+++ b/xmloff/source/forms/layerexport.hxx
@@ -104,7 +104,7 @@ namespace xmloff
MapPropertySet2Map::iterator
m_aCurrentPageIds;
- // the iterator for the control id map for the page beeing handled
+ // the iterator for the control id map for the page being handled
MapPropertySet2Map::iterator
m_aCurrentPageReferring;
// the same for the map of referring controls
diff --git a/xmloff/source/text/txtflde.cxx b/xmloff/source/text/txtflde.cxx
index 3eee437e7957..607a1d211dad 100644
--- a/xmloff/source/text/txtflde.cxx
+++ b/xmloff/source/text/txtflde.cxx
@@ -1198,7 +1198,7 @@ void XMLTextFieldExport::ExportFieldHelper(
{
// sequence field: name, formula, seq-format
OUString sName = GetStringProperty(sPropertyVariableName, rPropSet);
- // TODO: use reference name only if actually beeing referenced.
+ // TODO: use reference name only if actually being referenced.
ProcessString(XML_REF_NAME,
MakeSequenceRefName(
GetInt16Property(sPropertySequenceValue, rPropSet),
diff --git a/xmloff/source/forms/elementimport.hxx b/xmloff/source/forms/elementimport.hxx
index fa73f5a02304..b9f0c5466353 100644
--- a/xmloff/source/forms/elementimport.hxx
+++ b/xmloff/source/forms/elementimport.hxx
@@ -95,7 +95,7 @@ namespace xmloff
@param _rImport
the importer
@param _rEventManager
- the event attacher manager for the control beeing imported
+ the event attacher manager for the control being imported
@param _nPrefix
the namespace prefix
@param _rName
@@ -307,7 +307,7 @@ namespace xmloff
class OReferredControlImport : public OControlImport
{
protected:
- OUString m_sReferringControls; // the list of ids of controls referring to the one beeing imported
+ OUString m_sReferringControls; // the list of ids of controls referring to the one being imported
public:
OReferredControlImport(